@@ -5,9 +5,8 @@ import {
   ServerControllerProps
 } from './types';
 import { ServerDetailForm } from './ServerDetailForm';
-import { GDPSController } from './gdps';
 import { DBController } from './database';
-import { editIcon } from '@jupyterlab/ui-components';
+import { editIcon, deleteIcon } from '@jupyterlab/ui-components';
 
 export class ServerController extends React.Component<
   ServerControllerProps,
@@ -23,6 +22,7 @@ export class ServerController extends React.Component<
     this.setEditingState = this.setEditingState.bind(this);
     this.updateServer = this.updateServer.bind(this);
     this.handleExit = this.handleExit.bind(this);
+    this.deleteServer = this.deleteServer.bind(this);
   }
 
   setEditingState(state: boolean): void {
@@ -37,6 +37,10 @@ export class ServerController extends React.Component<
     this.props.updateServer(this.props.id, newServer);
   }
 
+  deleteServer(): void {
+    this.props.deleteServer(this.props.id);
+  }
+
   handleExit(): void {
     this.setState({ renderView: 'default' });
   }
@@ -51,26 +55,11 @@ export class ServerController extends React.Component<
             hostOS={this.props.hostOS}
             restPort={this.props.restPort}
             gsqlPort={this.props.gsqlPort}
-            gdpsPort={this.props.gdpsPort}
             setEditingState={this.setEditingState}
             submitServerDetail={this.updateServer}
           />
         </fieldset>
       );
-    } else if (this.state.renderView === 'gdps') {
-      return (
-        <fieldset>
-          <GDPSController
-            handleExit={this.handleExit}
-            serverAddress={this.props.serverAddress}
-            gdpsPort={this.props.gdpsPort}
-            jupyterApp={this.props.jupyterApp}
-            hostOS={this.props.hostOS}
-            restPort={this.props.restPort}
-            gsqlPort={this.props.gsqlPort}
-          />
-        </fieldset>
-      );
     } else if (this.state.renderView === 'database') {
       return (
         <fieldset>
@@ -101,13 +90,21 @@ export class ServerController extends React.Component<
                 padding="0px"
               />
             </button>
+            <button
+              className="btn-invisible"
+              onClick={() => this.deleteServer()}
+            >
+              <deleteIcon.react
+                height="14px"
+                margin-bottom="-2px"
+                margin-left="2px"
+                padding="0px"
+              />
+            </button>
           </p>
           <button onClick={() => this.setState({ renderView: 'database' })}>
             GraphStudio
           </button>
-          <button onClick={() => this.setState({ renderView: 'gdps' })}>
-            GDPS
-          </button>
         </fieldset>
       );
     }
